from django.db import models


class PlaythroughManager(models.Manager):
    def get_queryset(self):
        return (
            super()
            .get_queryset()
            .annotate(
                duration=models.ExpressionWrapper(
                    models.F("end") - models.F("start"),
                    output_field=models.DurationField(),
                )
            )
        )


class Playthrough(models.Model):
    session = models.UUIDField(unique=True)
    email = models.EmailField(unique=True)
    start = models.DateTimeField(auto_now_add=True)
    end = models.DateTimeField(null=True, blank=True)

    objects = PlaythroughManager()